This function takes in a prcomp object and returns the center and scale
vectors a list that can be used in metamoRph::metamoRph.
Usage
extract_prcomp_scaling(prcomp_object)
Arguments
- prcomp_object
A precomputed prcomp object
Value
a list object containing the prcomp "center" and "scale"
values for use in the metamoRph function
Details
This function is used by metamoRph::run_pca