model_apply
model_apply.RdThis function uses the output from model_build()
Usage
model_apply(
list_of_models,
experiment_data,
experiment_labels = "",
return_predictions = FALSE
)Arguments
- list_of_models
list object containing one model per sample type (e.g. photoreceptors vs not-photoreceptors)
- experiment_data
Projected data
metamoRph()- experiment_labels
Optional labels for the users experiment_data
- return_predictions
By default the predicted labels are returned. If set to TRUE, then the entire matrix of probabilities for each sample (against each label type) is returned.